@@ -1,40 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Commercial License Agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Nokia.
-**
 ** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this
+** file. Please review the following information to ensure the GNU Lesser
+** General Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** Alternatively, this file may be used under the terms of the GNU General
+** Public License version 3.0 as published by the Free Software Foundation
+** and appearing in the file LICENSE.GPL included in the packaging of this
+** file. Please review the following information to ensure the GNU General
+** Public License version 3.0 requirements will be met:
+** http://www.gnu.org/copyleft/gpl.html.
+**
+** Other Usage
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
+**
+**
+**
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -70,12 +70,13 @@ SpreadSheet::SpreadSheet(int rows, int cols, QWidget *parent)
     updateColor(0);
     setupMenuBar();
     setupContents();
+    setupContextMenu();
     setCentralWidget(table);
 
     statusBar();
-    connect(table, SIGNAL(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)),
+    connect(table, SIGNAL(currentItemChanged(QTableWidgetItem*,QTableWidgetItem*)),
             this, SLOT(updateStatus(QTableWidgetItem*)));
-    connect(table, SIGNAL(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)),
+    connect(table, SIGNAL(currentItemChanged(QTableWidgetItem*,QTableWidgetItem*)),
             this, SLOT(updateColor(QTableWidgetItem*)));
     connect(table, SIGNAL(currentItemChanged(QTableWidgetItem*,QTableWidgetItem*)),
             this, SLOT(updateLineEdit(QTableWidgetItem*)));
@@ -420,7 +421,7 @@ void SpreadSheet::actionMath_helper(const QString &title, const QString &op)
                        &cell1, &cell2, &out)) {
         int row, col;
         decode_pos(out, &row, &col);
-        table->item(row, col)->setText(tr("%1, %2, %3").arg(op, cell1, cell2));
+        table->item(row, col)->setText(tr("%1 %2 %3").arg(op, cell1, cell2));
     }
 }
 
@@ -481,7 +482,7 @@ void SpreadSheet::setupContents()
     table->setItem(3, 0, new SpreadSheetItem("Lunch"));
     table->setItem(4, 0, new SpreadSheetItem("Flight (LA)"));
     table->setItem(5, 0, new SpreadSheetItem("Taxi"));
-    table->setItem(6, 0, new SpreadSheetItem("Diinner"));
+    table->setItem(6, 0, new SpreadSheetItem("Dinner"));
     table->setItem(7, 0, new SpreadSheetItem("Hotel"));
     table->setItem(8, 0, new SpreadSheetItem("Flight (Oslo)"));
     table->setItem(9, 0, new SpreadSheetItem("Total:"));
@@ -510,7 +511,7 @@ void SpreadSheet::setupContents()
     // column 2
     table->setItem(0, 2, new SpreadSheetItem("Price"));
     table->item(0, 2)->setBackgroundColor(titleBackground);
-    table->item(0, 2)->setToolTip("This collumn shows the price of the purchase");
+    table->item(0, 2)->setToolTip("This column shows the price of the purchase");
     table->item(0, 2)->setFont(titleFont);
 
     table->setItem(1, 2, new SpreadSheetItem("150"));
@@ -523,6 +524,7 @@ void SpreadSheet::setupContents()
     table->setItem(8, 2, new SpreadSheetItem("1240"));
 
     table->setItem(9, 2, new SpreadSheetItem());
+    table->item(9, 2)->setBackgroundColor(Qt::lightGray);
 
     // column 3
     table->setItem(0, 3, new SpreadSheetItem("Currency"));
@@ -623,8 +625,8 @@ void SpreadSheet::print()
     QPrintPreviewDialog dlg(&printer);
     PrintView view;
     view.setModel(table->model());
-    connect(&dlg, SIGNAL(paintRequested(QPrinter *)),
-            &view, SLOT(print(QPrinter *)));
+    connect(&dlg, SIGNAL(paintRequested(QPrinter*)),
+            &view, SLOT(print(QPrinter*)));
     dlg.exec();
 #endif
 }
