@@ -1,43 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:BSD$
+** You may use this file under the terms of the BSD license as follows:
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** "Redistribution and use in source and binary forms, with or without
+** modification, are permitted provided that the following conditions are
+** met:
+**   * Redistributions of source code must retain the above copyright
+**     notice, this list of conditions and the following disclaimer.
+**   * Redistributions in binary form must reproduce the above copyright
+**     notice, this list of conditions and the following disclaimer in
+**     the documentation and/or other materials provided with the
+**     distribution.
+**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
+**     the names of its contributors may be used to endorse or promote
+**     products derived from this software without specific prior written
+**     permission.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
-**
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -48,6 +45,7 @@
 #include "button.h"
 #include "calculator.h"
 
+//! [0]
 Calculator::Calculator(QWidget *parent)
     : QDialog(parent)
 {
@@ -55,8 +53,11 @@ Calculator::Calculator(QWidget *parent)
     sumSoFar = 0.0;
     factorSoFar = 0.0;
     waitingForOperand = true;
+//! [0]
 
+//! [1]
     display = new QLineEdit("0");
+//! [1] //! [2]
     display->setReadOnly(true);
     display->setAlignment(Qt::AlignRight);
     display->setMaxLength(15);
@@ -64,52 +65,39 @@ Calculator::Calculator(QWidget *parent)
     QFont font = display->font();
     font.setPointSize(font.pointSize() + 8);
     display->setFont(font);
+//! [2]
 
-    QColor digitColor(150, 205, 205);
-    QColor backspaceColor(225, 185, 135);
-    QColor memoryColor(100, 155, 155);
-    QColor operatorColor(155, 175, 195);
-
+//! [4]
     for (int i = 0; i < NumDigitButtons; ++i) {
-	digitButtons[i] = createButton(QString::number(i), digitColor,
-                                       SLOT(digitClicked()));
+	digitButtons[i] = createButton(QString::number(i), SLOT(digitClicked()));
     }
 
-    Button *pointButton = createButton(tr("."), digitColor, SLOT(pointClicked()));
-    Button *changeSignButton = createButton(tr("\261"), digitColor, SLOT(changeSignClicked()));
+    Button *pointButton = createButton(tr("."), SLOT(pointClicked()));
+    Button *changeSignButton = createButton(tr("\261"), SLOT(changeSignClicked()));
 
-    Button *backspaceButton = createButton(tr("Backspace"), backspaceColor,
-                                   SLOT(backspaceClicked()));
-    Button *clearButton = createButton(tr("Clear"), backspaceColor, SLOT(clear()));
-    Button *clearAllButton = createButton(tr("Clear All"), backspaceColor.light(120),
-                                  SLOT(clearAll()));
+    Button *backspaceButton = createButton(tr("Backspace"), SLOT(backspaceClicked()));
+    Button *clearButton = createButton(tr("Clear"), SLOT(clear()));
+    Button *clearAllButton = createButton(tr("Clear All"), SLOT(clearAll()));
 
-    Button *clearMemoryButton = createButton(tr("MC"), memoryColor,
-                                     SLOT(clearMemory()));
-    Button *readMemoryButton = createButton(tr("MR"), memoryColor, SLOT(readMemory()));
-    Button *setMemoryButton = createButton(tr("MS"), memoryColor, SLOT(setMemory()));
-    Button *addToMemoryButton = createButton(tr("M+"), memoryColor,
-                                     SLOT(addToMemory()));
+    Button *clearMemoryButton = createButton(tr("MC"), SLOT(clearMemory()));
+    Button *readMemoryButton = createButton(tr("MR"), SLOT(readMemory()));
+    Button *setMemoryButton = createButton(tr("MS"), SLOT(setMemory()));
+    Button *addToMemoryButton = createButton(tr("M+"), SLOT(addToMemory()));
 
-    Button *divisionButton = createButton(tr("\367"), operatorColor,
-                                  SLOT(multiplicativeOperatorClicked()));
-    Button *timesButton = createButton(tr("\327"), operatorColor,
-                               SLOT(multiplicativeOperatorClicked()));
-    Button *minusButton = createButton(tr("-"), operatorColor,
-                               SLOT(additiveOperatorClicked()));
-    Button *plusButton = createButton(tr("+"), operatorColor,
-                              SLOT(additiveOperatorClicked()));
+    Button *divisionButton = createButton(tr("\367"), SLOT(multiplicativeOperatorClicked()));
+    Button *timesButton = createButton(tr("\327"), SLOT(multiplicativeOperatorClicked()));
+    Button *minusButton = createButton(tr("-"), SLOT(additiveOperatorClicked()));
+    Button *plusButton = createButton(tr("+"), SLOT(additiveOperatorClicked()));
 
-    Button *squareRootButton = createButton(tr("Sqrt"), operatorColor,
-                                    SLOT(unaryOperatorClicked()));
-    Button *powerButton = createButton(tr("x\262"), operatorColor,
-                               SLOT(unaryOperatorClicked()));
-    Button *reciprocalButton = createButton(tr("1/x"), operatorColor,
-                                    SLOT(unaryOperatorClicked()));
-    Button *equalButton = createButton(tr("="), operatorColor.light(120),
-                               SLOT(equalClicked()));
+    Button *squareRootButton = createButton(tr("Sqrt"), SLOT(unaryOperatorClicked()));
+    Button *powerButton = createButton(tr("x\262"), SLOT(unaryOperatorClicked()));
+    Button *reciprocalButton = createButton(tr("1/x"), SLOT(unaryOperatorClicked()));
+    Button *equalButton = createButton(tr("="), SLOT(equalClicked()));
+//! [4]
 
+//! [5]
     QGridLayout *mainLayout = new QGridLayout;
+//! [5] //! [6]
     mainLayout->setSizeConstraint(QLayout::SetFixedSize);
 
     mainLayout->addWidget(display, 0, 0, 1, 6);
@@ -145,7 +133,9 @@ Calculator::Calculator(QWidget *parent)
 
     setWindowTitle(tr("Calculator"));
 }
+//! [6]
 
+//! [7]
 void Calculator::digitClicked()
 {
     Button *clickedButton = qobject_cast<Button *>(sender());
@@ -159,8 +149,11 @@ void Calculator::digitClicked()
     }
     display->setText(display->text() + QString::number(digitValue));
 }
+//! [7]
 
+//! [8]
 void Calculator::unaryOperatorClicked()
+//! [8] //! [9]
 {
     Button *clickedButton = qobject_cast<Button *>(sender());
     QString clickedOperator = clickedButton->text();
@@ -185,14 +178,19 @@ void Calculator::unaryOperatorClicked()
     display->setText(QString::number(result));
     waitingForOperand = true;
 }
+//! [9]
 
+//! [10]
 void Calculator::additiveOperatorClicked()
+//! [10] //! [11]
 {
     Button *clickedButton = qobject_cast<Button *>(sender());
     QString clickedOperator = clickedButton->text();
     double operand = display->text().toDouble();
 
+//! [11] //! [12]
     if (!pendingMultiplicativeOperator.isEmpty()) {
+//! [12] //! [13]
         if (!calculate(operand, pendingMultiplicativeOperator)) {
             abortOperation();
 	    return;
@@ -203,7 +201,9 @@ void Calculator::additiveOperatorClicked()
         pendingMultiplicativeOperator.clear();
     }
 
+//! [13] //! [14]
     if (!pendingAdditiveOperator.isEmpty()) {
+//! [14] //! [15]
         if (!calculate(operand, pendingAdditiveOperator)) {
             abortOperation();
 	    return;
@@ -213,10 +213,14 @@ void Calculator::additiveOperatorClicked()
         sumSoFar = operand;
     }
 
+//! [15] //! [16]
     pendingAdditiveOperator = clickedOperator;
+//! [16] //! [17]
     waitingForOperand = true;
 }
+//! [17]
 
+//! [18]
 void Calculator::multiplicativeOperatorClicked()
 {
     Button *clickedButton = qobject_cast<Button *>(sender());
@@ -236,7 +240,9 @@ void Calculator::multiplicativeOperatorClicked()
     pendingMultiplicativeOperator = clickedOperator;
     waitingForOperand = true;
 }
+//! [18]
 
+//! [20]
 void Calculator::equalClicked()
 {
     double operand = display->text().toDouble();
@@ -264,7 +270,9 @@ void Calculator::equalClicked()
     sumSoFar = 0.0;
     waitingForOperand = true;
 }
+//! [20]
 
+//! [22]
 void Calculator::pointClicked()
 {
     if (waitingForOperand)
@@ -273,7 +281,9 @@ void Calculator::pointClicked()
         display->setText(display->text() + tr("."));
     waitingForOperand = false;
 }
+//! [22]
 
+//! [24]
 void Calculator::changeSignClicked()
 {
     QString text = display->text();
@@ -286,7 +296,9 @@ void Calculator::changeSignClicked()
     }
     display->setText(text);
 }
+//! [24]
 
+//! [26]
 void Calculator::backspaceClicked()
 {
     if (waitingForOperand)
@@ -300,7 +312,9 @@ void Calculator::backspaceClicked()
     }
     display->setText(text);
 }
+//! [26]
 
+//! [28]
 void Calculator::clear()
 {
     if (waitingForOperand)
@@ -309,7 +323,9 @@ void Calculator::clear()
     display->setText("0");
     waitingForOperand = true;
 }
+//! [28]
 
+//! [30]
 void Calculator::clearAll()
 {
     sumSoFar = 0.0;
@@ -319,7 +335,9 @@ void Calculator::clearAll()
     display->setText("0");
     waitingForOperand = true;
 }
+//! [30]
 
+//! [32]
 void Calculator::clearMemory()
 {
     sumInMemory = 0.0;
@@ -342,21 +360,25 @@ void Calculator::addToMemory()
     equalClicked();
     sumInMemory += display->text().toDouble();
 }
-
-Button *Calculator::createButton(const QString &text, const QColor &color,
-                                 const char *member)
+//! [32]
+//! [34]
+Button *Calculator::createButton(const QString &text, const char *member)
 {
-    Button *button = new Button(text, color);
+    Button *button = new Button(text);
     connect(button, SIGNAL(clicked()), this, member);
     return button;
 }
+//! [34]
 
+//! [36]
 void Calculator::abortOperation()
 {
     clearAll();
     display->setText(tr("####"));
 }
+//! [36]
 
+//! [38]
 bool Calculator::calculate(double rightOperand, const QString &pendingOperator)
 {
     if (pendingOperator == tr("+")) {
@@ -372,3 +394,4 @@ bool Calculator::calculate(double rightOperand, const QString &pendingOperator)
     }
     return true;
 }
+//! [38]
